pygeodesy.solveBase._SolveGDictBase

Package pygeodesy :: Module solveBase :: Class _SolveGDictBase |
[frames] | no frames]

# Class _SolveGDictBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
              _SolveCapsBase --+
                               |
                      _SolveBase --+
                                   |
                         _Solve3Base --+
                                       |
                                      _SolveGDictBase

Known Subclasses:
  - geodsolve._GeodesicSolveBase
  - , _SolveGDictLineBase
  - , rhumb.solve._RhumbSolveBase

(NTERNAL) Base class for `_GeodesicSolveBase` and `_RhumbSolveBase`.

Instance Methods
ArcDirect(self, lat1, lon1, azi1, a12, outmask=`'``UNUSED``'`) Return the `Direct` result at `a12` degrees. |
Direct(self, lat1, lon1, azi1, s12, outmask=`'``UNUSED``'`) Return the `Direct` result at distance `s12`. |
Inverse(self, lat1, lon1, lat2, lon2, outmask=`'``UNUSED``'`) Return the `Inverse` result. |
Inverse1(self, lat1, lon1, lat2, lon2, wrap=False) Return the non-negative, angular distance in `degrees`. |
__init__(self, a_ellipsoid=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, path='', **name) New `Solve` instance. |
toStr(self, **prec_sep_other) Return this `_Solve` as string. |
Inherited from `_SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
Inherited from `_SolveBase`: `reverse2`, `unroll` Inherited from `_SolveCapsBase`: `Exact`, `a`, `b`, `datum`, `ellipsoid`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_ellipsoid=Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=298.257223`...`, f=None, path='', **name) (Constructor) |
New `Solve` instance. Arguments: `a_ellipsoid` - An ellipsoid (Ellipsoid) or datum (Datum) or the equatorial radius of the ellipsoid (`scalar`, conventionally in `meter`), see `f`. `f` - The flattening of the ellipsoid (`scalar`) if `a_ellipsoid` is specified as `scalar`. `path` - Optionally, the (fully qualified) path to the `GeodSolve` or `RhumbSolve` executable (`filename`). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `a_ellipsoid` or `f`. Overrides: object.__init__

### toStr (self, **prec_sep_other) |
Return this `_Solve` as string. Arguments: `prec_sep` - See toStr. Overrides: named._Named.toStr